@@ -292,6 +292,18 @@ class DLQuery(object):
         self.params['values'] = rows
         return self # method chaining
 
+    #
+    # SEARCH TABLE
+    #
+
+    def search_table(self, table_name):
+        self.params['search_table'] = table_name
+        return self # method chaining
+
+    def with_query(self, query_text):
+        self.params['with_query'] = query_text
+        return self # method chaining
+
     #
     # SELECT
     #
@@ -334,10 +346,6 @@ class DLQuery(object):
         self.params['order_by'] = expr_array
         return self # method chaining
 
-    def search(self, query_text):
-        self.params['search'] = query_text
-        return self # method chaining
-
     #
     # SHOW DATABASES
     #
